@@ -15,6 +15,7 @@ import pyproj
 import rasterio as rio
 import rasterio.features as rio_features
 import rasterio.transform as rio_transform
+import rioxarray as rxr
 import shapely.geometry as sgeom
 import ujson as json
 import xarray as xr
@@ -190,12 +191,10 @@ def _rings2geojson(rings: List[List[List[float]]]) -> Dict[str, Any]:
     outer_rings, holes = _get_outer_rings(rings)
     uncontained_holes = _get_uncontained_holes(outer_rings, holes)
 
-    # if we couldn't match any holes using contains we can try intersects...
     while uncontained_holes:
         # pop a hole off out stack
         hole = uncontained_holes.pop()
 
-        # loop over all outer rings and see if any intersect our hole.
         intersects = False
         x = len(outer_rings) - 1
         while x >= 0:
@@ -203,7 +202,6 @@ def _rings2geojson(rings: List[List[List[float]]]) -> Dict[str, Any]:
             l1, l2 = LineString(outer_ring), LineString(hole)
             intersects = l1.intersects(l2)
             if intersects:
-                # the hole is contained push it into our polygon
                 outer_rings[x].append(hole)  # type: ignore
                 intersects = True
                 break
@@ -246,12 +244,9 @@ def _get_uncontained_holes(
     """Get all the uncontstrained holes."""
     uncontained_holes = []
 
-    # while there are holes left...
     while holes:
-        # pop a hole off out stack
         hole = holes.pop()
 
-        # loop over all outer rings and see if they contain our hole.
         contained = False
         x = len(outer_rings) - 1
         while x >= 0:
@@ -261,7 +256,6 @@ def _get_uncontained_holes(
             intersects = l1.intersects(l2)
             contains = l1.contains(p2)
             if not intersects and contains:
-                # the hole is contained push it into our polygon
                 outer_rings[x].append(hole)  # type: ignore
                 contained = True
                 break
@@ -281,6 +275,7 @@ def gtiff2xarray(
     ds_dims: Optional[Tuple[str, str]] = None,
     driver: Optional[str] = None,
     all_touched: bool = False,
+    nodata: Union[float, int, None] = None,
 ) -> Union[xr.DataArray, xr.Dataset]:
     """Convert (Geo)Tiff byte responses to ``xarray.Dataset``.
 
@@ -303,7 +298,9 @@ def gtiff2xarray(
     all_touched : bool, optional
         Include a pixel in the mask if it touches any of the shapes.
         If False (default), include a pixel only if its center is within one
-        of the shapes, or if it is selected by Bresenham’s line algorithm.
+        of the shapes, or if it is selected by Bresenham's line algorithm.
+    nodata : float or int, optional
+        The nodata value of the raster, defaults to None, i.e., is determined from the raster.
 
     Returns
     -------
@@ -323,7 +320,7 @@ def gtiff2xarray(
     else:
         var_name = dict(zip(r_dict, r_dict))
 
-    attrs = get_gtiff_attrs(r_dict[key1], ds_dims, driver)
+    attrs = get_gtiff_attrs(r_dict[key1], ds_dims, driver, nodata)
 
     tmp_dir = tempfile.gettempdir()
 
@@ -331,12 +328,13 @@ def gtiff2xarray(
         with rio.MemoryFile() as memfile:
             memfile.write(resp)
             with memfile.open(driver=driver) as vrt:
-                ds = xr.open_rasterio(vrt)
+                ds = rxr.open_rasterio(vrt)
                 with contextlib.suppress(ValueError):
                     ds = ds.squeeze("band", drop=True)
                 ds = ds.sortby(attrs.dims[0], ascending=False)
                 ds.attrs["crs"] = attrs.crs.to_string()
                 ds.attrs["transform"] = attrs.transform
+                ds.attrs["nodatavals"] = (attrs.nodata,)
                 ds.name = var_name[lyr]
                 fpath = Path(tmp_dir, f"{uuid.uuid4().hex}.nc")
                 ds.to_netcdf(fpath)
@@ -345,34 +343,20 @@ def gtiff2xarray(
     ds = xr.open_mfdataset(
         (to_dataset(lyr, resp) for lyr, resp in r_dict.items()),
         parallel=True,
+        decode_coords="all",
     )
-    if len(ds.variables) - len(ds.dims) == 1:
-        ds = ds[list(ds.keys())[0]]
+    variables = list(ds)
+    if len(variables) == 1:
+        ds = ds[variables[0]]
     ds = ds.sortby(attrs.dims[0], ascending=False)
     ds.attrs["crs"] = attrs.crs.to_string()
     ds.attrs["nodatavals"] = (attrs.nodata,)
     transform, _, _ = get_transform(ds, attrs.dims)
     ds.attrs["transform"] = transform2tuple(transform)
     ds.attrs["res"] = (transform.a, transform.e)
-
-    ds = attrs2tuple(ds, ["scales", "offsets"])
-    if isinstance(ds, xr.Dataset):
-        for v in ds.keys():
-            ds[v] = attrs2tuple(ds[v], ["scales", "offsets"])
-
     return xarray_geomask(ds, geometry, geo_crs, attrs.dims, all_touched)
 
 
-def attrs2tuple(
-    ds: Union[xr.Dataset, xr.DataArray], attrs: List[str]
-) -> Union[xr.Dataset, xr.DataArray]:
-    """Convert the floats attributes of a dataset or dataarray to a tuple."""
-    for attr in attrs:
-        if attr in ds.attrs and not isinstance(ds.attrs[attr], tuple):
-            ds.attrs[attr] = (ds.attrs[attr],)
-    return ds
-
-
 def xarray_geomask(
     ds: Union[xr.Dataset, xr.DataArray],
     geometry: Union[Polygon, MultiPolygon, Tuple[float, float, float, float]],
@@ -404,9 +388,8 @@ def xarray_geomask(
     xarray.Dataset or xarray.DataArray
         The input dataset with a mask applied (np.nan)
     """
-    attrs = ds.attrs
-    if "crs" not in attrs:
-        raise MissingAttribute("crs", list(attrs.keys()))
+    if "crs" not in ds.attrs:
+        raise MissingAttribute("crs", list(ds.attrs.keys()))
 
     if ds_dims is None:
         ds_dims = _get_dim_names(ds)
@@ -426,25 +409,33 @@ def xarray_geomask(
     mask = xr.DataArray(_mask, coords, dims=ds_dims)
 
     ds_masked = ds.where(mask, drop=True)
-    ds_masked.attrs = attrs
+    ds_masked.attrs = ds.attrs
     ds_masked.attrs["transform"] = transform2tuple(transform)
     ds_masked.attrs["bounds"] = _geometry.bounds
     ds_masked.attrs["res"] = (transform.a, transform.e)
-
+    if isinstance(ds_masked, xr.Dataset):
+        for v in ds_masked:
+            ds_masked[v].attrs = ds[v].attrs
+            ds_masked[v].attrs["transform"] = transform2tuple(transform)
+            ds_masked[v].attrs["bounds"] = _geometry.bounds
+            ds_masked[v].attrs["res"] = (transform.a, transform.e)
     return ds_masked
 
 
 class Attrs(NamedTuple):
     """Attributes of a GTiff byte response."""
 
-    nodata: np.float64
-    crs: pyproj.crs.crs.CRS
+    nodata: Union[float, int]
+    crs: pyproj.CRS
     dims: Tuple[str, str]
     transform: Tuple[float, float, float, float, float, float]
 
 
 def get_gtiff_attrs(
-    resp: bytes, ds_dims: Optional[Tuple[str, str]] = None, driver: Optional[str] = None
+    resp: bytes,
+    ds_dims: Optional[Tuple[str, str]] = None,
+    driver: Optional[str] = None,
+    nodata: Union[float, int, None] = None,
 ) -> Attrs:
     """Get nodata, CRS, and dimension names in (vertical, horizontal) order from raster in bytes.
 
@@ -459,10 +450,12 @@ def get_gtiff_attrs(
     driver : str, optional
         A GDAL driver for reading the content, defaults to automatic detection. A list of
         the drivers can be found here: https://gdal.org/drivers/raster/index.html
+    nodata : float or int, optional
+        The nodata value of the raster, defaults to None, i.e., is determined from the raster.
 
     Returns
     -------
-    dict
+    Attrs
         No data, CRS, and dimension names for vertical and horizontal directions or
         a list of the existing dimensions if they are not in a list of common names.
     """
@@ -470,15 +463,19 @@ def get_gtiff_attrs(
         memfile.write(resp)
         with memfile.open(driver=driver) as src:
             r_crs = pyproj.CRS(src.crs)
-            if src.nodata is None:
-                try:
-                    nodata = np.iinfo(src.dtypes[0]).max
-                except ValueError:
-                    nodata = np.nan
-            else:
-                nodata = np.dtype(src.dtypes[0]).type(src.nodata)
 
-            ds = xr.open_rasterio(src)
+            if nodata is None:
+                if src.nodata is None:
+                    try:
+                        _nodata = np.iinfo(src.dtypes[0]).max
+                    except ValueError:
+                        _nodata = np.nan
+                else:
+                    _nodata = np.dtype(src.dtypes[0]).type(src.nodata)
+            else:
+                _nodata = nodata
+
+            ds = rxr.open_rasterio(src)
             if ds_dims is None:
                 ds_dims = _get_dim_names(ds)
 
@@ -489,7 +486,7 @@ def get_gtiff_attrs(
                 transform = transform2tuple(src.transform)
             else:
                 transform = src.transform  # type: ignore
-    return Attrs(nodata, r_crs, ds_dims, transform)
+    return Attrs(_nodata, r_crs, ds_dims, transform)
 
 
 def _get_dim_names(ds: Union[xr.DataArray, xr.Dataset]) -> Optional[Tuple[str, str]]:
@@ -517,6 +514,7 @@ def get_transform(
         The dataset(array) to be masked
     ds_dims : tuple, optional
         Names of the coordinames in the dataset, defaults to ``("y", "x")``.
+        The order of the dimension names must be (vertical, horizontal).
 
     Returns
     -------
